@@ -373,7 +373,7 @@ public:
     BigInteger getActiveInputChannels() const override    { BigInteger b; b.setRange (0, actualNumberOfInputs, true);  return b; }
     int getOutputLatencyInSamples() override              { /* TODO */ return 0; }
     int getInputLatencyInSamples() override               { /* TODO */ return 0; }
-    int getXRunCount() const noexcept                     { return underruns; }
+    int getXRunCount() const noexcept override            { return underruns; }
 
     //==============================================================================
     static const char* const belaTypeName;
